@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/pd/getopt:RELEASE-3_2_0_104:getopt.c,v 1.4 1998/11/06 19:54:52 woods Exp"
+#ident	"@(#)smail/pd/getopt:RELEASE-3_2_0_105:getopt.c,v 1.5 1999/02/03 05:26:14 woods Exp"
  */
 /*
  * This file is in the public domain.
@@ -23,10 +23,22 @@
 #ifdef HAVE_STDLIB_H
 # include <stdlib.h>
 #endif
+#if defined(POSIX_OS)
+# include <limits.h>
+# include <unistd.h>
+#else /* not POSIX_OS */
+# if defined (HAVE_LIMITS_H)
+#  include <limits.h>
+# endif
+# if defined (HAVE_UNISTD_H)
+#  include <unistd.h>
+# endif
+#endif	/* not POSIX_OS */
 
 extern char *optarg;
 extern int optind, opterr;
 
+int getopt();
 void outarg();
 
 int prevopt = 0;
