@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:alloc.c,v 1.9 1997/12/16 22:11:41 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:alloc.c,v 1.15 1999/03/01 23:04:59 woods Exp"
  */
 
 /*
@@ -18,14 +18,14 @@
  *	    storage.
  *
  *	block storage allocation
- *	    This allows a given stroage allocation to be associated 
+ *	    This allows a given storage allocation to be associated 
  *	    with a group of other storage allocations.  It is
  *	    possible to free or test for existence of the class.
  *
  *	    A block a pointer to a chain of segments.  Each segment
  *	    refers to one storage allocation.  A block also contains
  *	    the total number of bytes allocated.  If this number is
- *	    zero, then no stroage is associated with the block.
+ *	    zero, then no storage is associated with the block.
  *
  *	external functions: xmalloc, xrealloc, xfree, 
  *			    balloc, brealloc, bfree,
@@ -33,6 +33,7 @@
  */
 #include <sys/types.h>
 #include <stdio.h>
+#include <errno.h>
 #include "defs.h"
 #ifdef HAVE_STDLIB_H
 # include <stdlib.h>
@@ -90,7 +91,7 @@ xmalloc(size)
 
     ret = malloc(size + sizeof(ALIGNED_TYPE));
     if (!ret) {
-	panic(EX_SOFTWARE, "malloc(%d) returned NULL", size);
+	panic(EX_SOFTWARE, "malloc(%d) failed: %s.", size, strerror(errno));
 	/*NOTREACHED*/
     }
     *(ALIGNED_TYPE *)ret = X_MAGIC;
@@ -115,8 +116,8 @@ xrealloc(region, size)
     ((ALIGNED_TYPE *)region)[-1] = 0;	/* clear the magic number */
     ret = realloc(region - sizeof(ALIGNED_TYPE), size + sizeof(ALIGNED_TYPE));
     if (!ret) {
-	panic(EX_SOFTWARE, "realloc(0x%lx, %u) returned NULL",
-	      (long)region, size);
+	panic(EX_SOFTWARE, "realloc(0x%lx, %u) failed: %s.",
+	      (long)region, size, strerror(errno));
 	/*NOTREACHED*/
     }
     *(ALIGNED_TYPE *)ret = X_MAGIC;	/* put a magic number back */
@@ -127,6 +128,10 @@ void
 xfree(region)
     char *region;
 {
+    if (region == NULL) {
+	panic(EX_SOFTWARE, "xfree(NULL) called!  Please trace under a debugger!");
+	/*NOTREACHED*/
+    }
     if (X_CHECK(region) == FAIL) {
 	/* it should be safe to ignore double free's */
 	return;
@@ -160,7 +165,7 @@ bmalloc(size, block)
 
     /* add a new segment to the block */
     if ((newseg = (struct bseg *)malloc(sizeof(struct bseg))) == NULL) {
-	panic(EX_SOFTWARE, "bmalloc: malloc of bseg failed");
+	panic(EX_SOFTWARE, "bmalloc: malloc of bseg [%d] failed: %s.", sizeof(struct bseg), strerror(errno));
 	/* NOTREACHED */
     }
     newseg->next = block->next;
@@ -168,7 +173,7 @@ bmalloc(size, block)
 
     /* allocate the storage */
     if ((newseg->data = malloc(size)) == NULL) {
-	panic(EX_SOFTWARE, "bmalloc: malloc of %d bytes failed", size);
+	panic(EX_SOFTWARE, "bmalloc: malloc of %d bytes failed: %s.", strerror(errno));
 	/* NOTREACHED */
     }
     ++block->cnt;
@@ -178,7 +183,7 @@ bmalloc(size, block)
 }
 
 /*
- * brealloc - reallocate stroage associated with a block
+ * brealloc - reallocate storage associated with a block
  *
  * Resize a storagg from a block, and perform all needed
  * accounting adjustments.
@@ -211,16 +216,16 @@ brealloc(data, size, block)
     }
     if (oldseg == NULL) {
 	panic(EX_SOFTWARE, 
-	    "brealloc: seg (at 0x%lx) not in block (at 0x%lx, cnt:%d)",
-	    (long)oldseg, (long)block, block->cnt);
+	      "brealloc: seg (at 0x%lx) not in block (at 0x%lx, cnt:%d)",
+	      (long)oldseg, (long)block, block->cnt);
 	/* NOTREACHED */
     }
 
     /* reallocate */
     if ((oldseg->data = realloc(data, size)) == NULL) {
 	panic(EX_SOFTWARE, 
-	    "brealloc: realloc to %d bytes (at 0x%lx) failed",
-	    size, (long)oldseg->data);
+	      "brealloc: realloc to %d bytes (at 0x%lx) failed: %s.",
+	      size, (long)oldseg->data, strerror(errno));
 	/* NOTREACHED */
     }
 
@@ -247,7 +252,7 @@ bfree(data, block)
 
     /* firewall */
     if (block == NULL) {
-	panic(EX_SOFTWARE, "brealloc: block is NULL");
+	panic(EX_SOFTWARE, "bfree: block is NULL");
 	/* NOTREACHED */
     }
 
