@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:alloc.h,v 1.8 1998/04/11 23:30:10 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:alloc.h,v 1.10 1999/02/03 06:03:29 woods Exp"
  */
 
 /*
@@ -13,14 +13,14 @@
 /*
  * alloc.h:
  *	block storage allocation
- * 	    This allows a given stroage allocation to be associated 
+ * 	    This allows a given storage allocation to be associated 
  *	    with a group of other storage allocations.  It is
  *	    possible to free or test for existence of the class.
  *
  *	    A block a pointer to a chain of segments.  Each segment
  *	    refers to one storage allocation.  A block also contains
  *	    the total number of segments allocated.  If this number is
- *	    zero, then no stroage is associated with the block.
+ *	    zero, then no storage is associated with the block.
  */
 
 /*
@@ -58,12 +58,12 @@ struct bseg {
  */
 #define X_MAGIC	  ((ALIGNED_TYPE)0xe8f987b1)
 #define X_CHECK(p)							\
-	(((ALIGNED_TYPE *)(p))[-1] != X_MAGIC?				\
+	(((ALIGNED_TYPE *)(p))[-1] != X_MAGIC ?				\
 		(write_log(WRITE_LOG_PANIC,				\
 			"X_CHECK failed!  ptr=0x%lx, line=%d, file=%s", \
 			(long)(p), __LINE__, __FILE__),			\
-		 x_dont_panic?						\
-		    FAIL:						\
+		 x_dont_panic ?						\
+		    FAIL :						\
 		    (abort(), 0))					\
 	    : SUCCEED)
  
