@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:bindlib.c,v 1.55 1998/11/20 00:22:42 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:bindlib.c,v 1.57 1999/02/03 06:46:48 woods Exp"
  */
 
 /*
@@ -480,7 +480,7 @@ bind_check_if_canonical_host(hostnm, inet, error_p)
     int result;
     int nothing;
 
-    DEBUG1(DBG_DRIVER_MID, "bind_check_if_canonical_host(%s) called.\n", hostnm);
+    DEBUG2(DBG_DRIVER_MID, "bind_check_if_canonical_host(%s, %s) called.\n", hostnm, inet_ntoa(*((struct in_addr *) &inet)));
 
 #ifdef RES_INIT
     /*  This initialises the resolver.  If the resolver is so old that RES_INIT
@@ -987,7 +987,7 @@ static int route_by_greybook(mxdat)
     if (mxdat->priv->uk_greybook_hosts_file != NULL) {
         int result;
         char * db_ptr;
-        char *error_text;
+        char *error_text = NULL;
         char *return_value;
 
         DEBUG1(DBG_ROUTE_HI, "Opening greybook hosts file %s\n", 
@@ -1889,7 +1889,7 @@ get_records(qname, qtype, answer, pack_size, error)
         return FILE_NOMATCH;
     }
 #else                                   /* not OBSOLETE_RESOLVER */
-    anslen = res_query(qname, C_IN, qtype, (u_char *) answer, MAXPACKET);
+    anslen = res_search(qname, C_IN, qtype, (u_char *) answer, MAXPACKET);
     if (anslen < 0) {
 	*error = (char *) hstrerror(h_errno); /* XXX cast is to explicitly discard const */
         switch (h_errno) {
