@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:config.h,v 1.63 1998/11/05 04:14:55 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:config.h,v 1.64 1999/02/03 05:25:29 woods Exp"
  */
 
 /*
@@ -1362,6 +1362,35 @@ ${if and{{origin:local} {def:owner}}\
 # endif
 #endif
 
+/*
+ * Setup for the pipe transport
+ *
+ * If you wish to modify the default pipe transport command, define
+ * PIPE_COMMAND in EDITME.  If you don't define it, it will default according to
+ * whether your system supports "#! /interpreter/path" at the beginning of an
+ * executable script or not (under the assumption that you'll want to allow
+ * scripts to be run from the pipe transport).
+ *
+ * NOTE:  You can use something like sendmail's "smrsh" to make the pipe
+ * transport more secure.  Eg. "/usr/libexec/smrsh -c ${user}"
+ *
+ * WARNING: whatever $user expands to will be passed as one argument
+ */
+#ifndef PIPE_COMMAND
+# if defined(HAVE_HASH_BANG)
+#  define PIPE_COMMAND "$user"
+# else
+#  if defined(SHELL_EXEC_PATH) && (defined(__STDC__) || defined(__cplusplus))
+#   define PIPE_COMMAND #SHELL_EXEC_PATH ## "-c $user"
+#  else
+#   if defined(SHELL_EXEC_PATH)
+#    include "ERROR: you must define PIPE_COMMAND manualy if SHELL_EXEC_PATH is set"
+#   else
+#    define PIPE_COMMAND "/bin/sh -c $user"
+#   endif
+#  endif
+# endif
+#endif
 
 /*
  * DEFAULT DIRECTOR CONFIGURATION
