@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:default.c,v 1.48 1998/10/29 02:44:46 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:default.c,v 1.50 1999/02/03 05:25:29 woods Exp"
  */
 
 /*
@@ -1000,14 +1000,7 @@ static struct transport local_transport = {
  * expand_string() before it is passed to build_cmd_line().
  */
 static struct pipe_private pipe_transport_priv = {
-#ifdef HAVE_SYS_INTERPRETER	/* NOTE: autoconf has AC_SYS_INTERPRETER but
-				 * does not define this manifest by itself.
-				 */
-    "$user",				/* command is passed as next_addr */
-#else
-    /* XXX should use SHELL_EXEC_PATH */
-    "/bin/sh -c ${shquote:user}",	/* command is passed as next_addr */
-#endif
+    PIPE_COMMAND,			/* command is passed as next_addr */
     NULL,				/* use uid of the recipient */
     NULL,				/* use gid of the recipient */
     0022,				/* umask for child process */
