@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:expand.c,v 1.28 1998/11/06 20:15:09 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:expand.c,v 1.29 1999/02/03 06:06:31 woods Exp"
  */
 
 /*
@@ -579,7 +579,7 @@ lookup_clause(addr, str, s, es)
     char *then_clause, *then_end, *else_clause, *else_end;
     struct str file_str;
     char *dbinfo;
-    char *error;
+    char *error = NULL;
     char *found = NULL;
     int success;
 
@@ -651,11 +651,11 @@ lookup_clause(addr, str, s, es)
      * expand the key, file, and proto
      */
 
+    STR_INIT(&file_str);
     xkey = substitute(addr, (char *)NULL, (char *)NULL, key, key_len);
     if (xkey == NULL)
 	goto do_else_clause;
     xkey = COPY_STRING(xkey);
-    STR_INIT(&file_str);
     xfile = rcopy(file, file + file_len);
     file = NULL;
     if (expand_string_to(&file_str, xfile, addr, (char *)NULL) == FAIL) {
