@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:lookup.c,v 1.38 1998/11/20 01:03:53 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:lookup.c,v 1.44 1999/02/03 05:53:20 woods Exp"
  */
 
 /*
@@ -288,6 +288,7 @@ lookup_database(db, key, valuep, errorp)
     DEBUG1(DBG_DRIVER_HI, "lookup_database(): looking for <%s>.\n", key);
 
     *valuep = (char *) NULL;
+    *errorp = (char *) NULL;
     ret = (*gdb->proto->lookup)(gdb, key, valuep, errorp);
 
     DEBUG4(DBG_DRIVER_HI,
@@ -1465,8 +1466,8 @@ aliasni_lookup(db, key, value, error)
 
 /* private data structure */
 struct nisplus_db {
-    char		*name;
     struct proto	*proto;
+    char		*name;
     char		*table;
     int			fieldnum;
     int			retries,	/* saved retry/interval for lookup */
@@ -1662,7 +1663,7 @@ nisplus_lookup(db, key, value, error)
     name = (char*) xmalloc(strlen(key)+strlen(db->table)+2);
     sprintf(name, db->table, key);
 
-    DEBUG1(DBG_DRIVER_HI, "nisplus_lookup: looking for <%s> in %s.\n", key, db->name);
+    DEBUG2(DBG_DRIVER_HI, "nisplus_lookup: looking for <%s> in %s.\n", key, db->name);
     DEBUG1(DBG_DRIVER_HI, "nisplus_lookup: asking NIS+ for <%s>\n", name);
 
     /* look up the object */
@@ -1847,6 +1848,9 @@ match_ip(ip, pattern)
 		wild = 1;
 	    }
 	    if (smtp_local_net && len > 0 && strncmpic("localnet", pat_p, len) == 0) {
+		DEBUG1(DBG_ADDR_HI,
+		       "(checking against 'localnet' pattern of '%s')\n",
+			smtp_local_net);
 		/* our pattern will be the string in smtp_local_net */
 		len = strlen(smtp_local_net);
 		if (smtp_local_net[len - 1] == '*') {
@@ -1877,7 +1881,7 @@ match_ip(ip, pattern)
 	if (*end_p == '\0')
 	    break;
     }
-    
+
     DEBUG2(DBG_ADDR_HI, "ip '%s' not verified by pattern '%s'\n",
 	   ip, pattern);
     
@@ -1898,7 +1902,7 @@ main(argc, argv)
     char *proto;
     char *name;
     char *db;
-    char *error;
+    char *error = NULL;
     int interval = 3;
     int retries = 0;
     int success;
