@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:main.c,v 1.50 1998/10/01 05:34:06 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:main.c,v 1.51 1999/02/03 04:10:09 woods Exp"
  */
 
 /*
@@ -329,7 +329,7 @@ main(argc, argv)
     }
 
     /* process the args given by the user */
-    process_args(argv);
+    process_args(argv, TRUE);
 
     if (prog_type == PROG_RUNQUEUE) {
 	if (operation_mode == MODE_DEFAULT ||
@@ -867,8 +867,9 @@ initialize_state()
  * processing based on name at invocation.
  */
 void
-process_args(args)
+process_args(args, restrict)
     register char **args;		/* vector of arguments */
+    int restrict;                       /* enforce rsmtp restrictions */
 {
     struct addr *cur;			/* temp addr list entry */
     char *arg;				/* single string from args */
@@ -912,7 +913,7 @@ process_args(args)
 		}
 		break;
 
-	    case 'D':
+	    case 'D':                   /* set debugging output file */
 		if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
 		    rmail_panic();
 		}
@@ -931,7 +932,7 @@ process_args(args)
 		break;
 
 	    case 'F':			/* set full name of sender */
-		if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
+		if ((prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) && restrict) {
 		    rmail_panic();
 		}
 		sender_name = arg;
@@ -950,7 +951,7 @@ process_args(args)
 		/* FALLTHRU */
 
 	    case 'f':			/* set path to sender */
-		if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
+		if ((prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) && restrict) {
 		    rmail_panic();
 		}
 		newsender = arg;
@@ -1135,7 +1136,7 @@ process_args(args)
 		}
 		switch (*arg++) {
 
-		case 'A':
+		case 'A':               /* name of aliases file */
 		    if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
 			rmail_panic();
 		    }
@@ -1203,7 +1204,7 @@ process_args(args)
 		    break;
 
 		case 'M':
-		    if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
+		    if ((prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) && restrict) {
 			rmail_panic();
 		    }
 		    if (*arg == '\0') {
