@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:modes.c,v 1.80 1998/11/20 00:27:31 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:modes.c,v 1.82 1999/02/03 04:10:09 woods Exp"
  */
 
 /*
@@ -1107,7 +1107,7 @@ daemon_mode()
 	     * will result in pushing the SYN attack into the realm of the
 	     * application, or not, is yet to be determined.
 	     */
-	    errno != ECONNRESET && errno != ENETUNREACH && errno != EHOSTUNREACH && errno != ENOTCONN && errno != ENETDOWN && errno != EHOSTDOWN && errno != errno != ECONREFUSED &&
+	    errno != ECONNRESET && errno != ENETUNREACH && errno != EHOSTUNREACH && errno != ENOTCONN && errno != ENETDOWN && errno != EHOSTDOWN && errno != errno != ECONNREFUSED &&
 #endif
 	    errno != EINTR) {
 	    unsigned int oldalarm;
@@ -2062,7 +2062,7 @@ do_smtp(in, out)
 		}
 
 		/* process arguments from the spool file */
-		process_args(argv);
+		process_args(argv, FALSE);
 
 		/* perform delivery */
 		deliver_mail();
@@ -2194,7 +2194,7 @@ process_one_spool_file(spfn)
     }
 
     /* process arguments from the spool file */
-    process_args(argv);
+    process_args(argv, FALSE);
 
     /* perform delivery */
     deliver_mail();
