@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:route.c,v 1.30 1998/11/20 01:01:26 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:route.c,v 1.31 1999/02/03 06:27:42 woods Exp"
  */
 
 /*
@@ -200,7 +200,7 @@ route_remote_addrs(in, out, retry, defer, fail)
 	}
 	if (cur->transport == NULL) {
 	    /* router did not compute a transport, we must */
-	    compute_transport(cur);
+	    compute_transport(cur, (cur->flags & ADDR_SMARTHOST) ? cur->target : cur->next_host);
 	    if (cur->error && (cur->error->info & ERR_CONFERR)) {
 		/* defer configuration errors */
 		cur->succ = *defer;
@@ -889,13 +889,14 @@ route_to_route_addr(p)
  * host names, where the special name `*' is a catchall.
  */
 static void
-compute_transport(addr)
+compute_transport(addr, host)
     struct addr *addr;
+    char *host;				/* host to match in "methods" */
 {
     struct router *rp = addr->router;
 
     DEBUG2(DBG_ROUTE_HI, "compute_transport called: host=%s, router=%s\n",
-	   addr->next_host, rp->name);
+	   host, rp->name);
     /* no transport yet assigned, look around for defaults */
     if (rp->method) {
 	/* there is a "method", table of possible transports */
@@ -903,7 +904,7 @@ compute_transport(addr)
 
 	mp = rp->method;
 	while (mp->host) {
-	    if ((EQIC(addr->next_host, mp->host) || EQ(mp->host, "*")) &&
+	    if ((EQIC(host, mp->host) || EQ(mp->host, "*")) &&
 		  (mp->mingrade < 0 ||
 		   (msg_grade >= mp->mingrade && msg_grade <= mp->maxgrade)))
 	    {
