@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_104:rewrite.c,v 1.14 1998/11/20 01:07:56 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_105:rewrite.c,v 1.15 1999/02/03 08:12:11 woods Exp"
  */
 /*
  * rewrite.c
@@ -372,10 +372,10 @@ rewrite_lookup(rp, addr, fl, rt_info, error_p)
     char *flag;		/* flag field from raw_data */
     char *format;	/* format field from raw_data */
     int form;		/* form of remainder */
-    char *error;	/* error from some lower-level functions */
+    char *error = NULL;	/* error from some lower-level functions */
     char *new_address;	/* rewritten address */
-    char *new_target;	/* target of rewritten address */
-    char *new_remainder; /* remainder of rewritten address */
+    char *new_target = NULL; /* target of rewritten address */
+    char *new_remainder = NULL; /* remainder of rewritten address */
 
     /* is the target in the database? */
     result = find_domain(rp, addr, &raw_data, &match, error_p);
