@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_104:smtprecv.c,v 1.81 1998/11/20 00:49:27 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_105:smtprecv.c,v 1.82 1999/02/03 06:19:56 woods Exp"
  */
 
 /*
@@ -452,11 +452,9 @@ receive_smtp(in, out)
 	case HELO_CMD:
 #ifdef HAVE_LIBWRAP
 	    if (out && smtp_session_denied) {
-		fprintf(out, "550 You%s%s%s are not permitted to send mail%s%s%s.\r\n",
-			sender_host_really ? " (i.e. " : "",
-			sender_host_really ? sender_host_really : "",
-			sender_host_really ? ")" : "",
-			sender_host_addr ? "from [" : "",
+		fprintf(out, "550 You (i.e. %s) are not permitted to send mail%s%s%s.\r\n",
+			sender_host_really ? sender_host_really : "<UNKNOWN>",
+			sender_host_addr ? " from [" : "",
 			sender_host_addr ? sender_host_addr : "",
 			sender_host_addr ? "]" : "");
 		fflush(out);
@@ -505,7 +503,7 @@ receive_smtp(in, out)
 			    error ? "-" : " ",
 			    ident_sender ? ident_sender : "",
 			    ident_sender ? "@" : "",
-			    sender_host_really ? sender_host_really : "",
+			    sender_host_really ? sender_host_really : "(UNKNOWN)",
 			    sender_host_addr ? " remote address [" : "",
 			    sender_host_addr ? sender_host_addr : "",
 			    sender_host_addr ? "]" : "",
@@ -587,10 +585,8 @@ receive_smtp(in, out)
 	case MAIL_CMD:
 #ifdef HAVE_LIBWRAP
 	    if (out && smtp_session_denied) {
-		fprintf(out, "550 You%s%s%s are not permitted to send mail%s%s%s.\r\n",
-			sender_host_really ? " (i.e. " : "",
-			sender_host_really ? sender_host_really : "",
-			sender_host_really ? ")" : "",
+		fprintf(out, "550 You (i.e. %s) are not permitted to send mail%s%s%s.\r\n",
+			sender_host_really ? sender_host_really : "<UNKNOWN>",
 			sender_host_addr ? "from [" : "",
 			sender_host_addr ? sender_host_addr : "",
 			sender_host_addr ? "]" : "");
@@ -773,10 +769,8 @@ receive_smtp(in, out)
 	case RCPT_CMD:
 #ifdef HAVE_LIBWRAP
 	    if (out && smtp_session_denied) {
-		fprintf(out, "550 You%s%s%s are not permitted to send mail%s%s%s.\r\n",
-			sender_host_really ? " (i.e. " : "",
-			sender_host_really ? sender_host_really : "",
-			sender_host_really ? ")" : "",
+		fprintf(out, "550 You (i.e. %s) are not permitted to send mail%s%s%s.\r\n",
+			sender_host_really ? sender_host_really : "<UNKNOWN>",
 			sender_host_addr ? "from [" : "",
 			sender_host_addr ? sender_host_addr : "",
 			sender_host_addr ? "]" : "");
@@ -967,10 +961,8 @@ receive_smtp(in, out)
 	case EXPN_CMD:
 #ifdef HAVE_LIBWRAP
 	    if (out && smtp_session_denied) {
-		fprintf(out, "550 You%s%s%s are not permitted to view lists%s%s%s.\r\n",
-			sender_host_really ? " (i.e. " : "",
-			sender_host_really ? sender_host_really : "",
-			sender_host_really ? ")" : "",
+		fprintf(out, "550 You (i.e. %s) are not permitted to view lists%s%s%s.\r\n",
+			sender_host_really ? sender_host_really : "<UNKNOWN>",
 			sender_host_addr ? "from [" : "",
 			sender_host_addr ? sender_host_addr : "",
 			sender_host_addr ? "]" : "");
@@ -1033,10 +1025,8 @@ receive_smtp(in, out)
 	case DEBUG_CMD:
 #ifdef HAVE_LIBWRAP
 	    if (out && smtp_session_denied) {
-		fprintf(out, "550 You%s%s%s are not permitted to use this command%s%s%s.\r\n",
-			sender_host_really ? " (i.e. " : "",
-			sender_host_really ? sender_host_really : "",
-			sender_host_really ? ")" : "",
+		fprintf(out, "550 You (i.e. %s) are not permitted to use this command%s%s%s.\r\n",
+			sender_host_really ? sender_host_really : "<UNKNOWN>",
 			sender_host_addr ? "from [" : "",
 			sender_host_addr ? sender_host_addr : "",
 			sender_host_addr ? "]" : "");
@@ -2143,11 +2133,11 @@ smtp_receive_timeout_sig(sig)
     fprintf(out_file, "421 %s SMTP command timeout, closing channel\r\n",
 	    primary_name);
     write_log(WRITE_LOG_SYS, "SMTP connection timeout%s%s%s%s%s.",
-	      sender_host? " while talking with ": "",
-	      sender_host? sender_host: "",
-	      sender_host_addr? " [": "",
-	      sender_host_addr? sender_host_addr: "",
-	      sender_host_addr? "]": "");
+	      sender_host ? " while talking with " : "",
+	      sender_host ? sender_host: "",
+	      sender_host_addr ? " [" : "",
+	      sender_host_addr ? sender_host_addr : "",
+	      sender_host_addr ? "]" : "");
     if (smtp_remove_on_timeout) {
 	unlink_spool();
     }
