@@ -1,6 +1,6 @@
 #! /bin/sh
 :
-#ident	"@(#)smail/util:RELEASE-3_2_0_104:checkerr.sh,v 1.9 1998/11/11 03:57:25 woods Exp"
+#ident	"@(#)smail/util:RELEASE-3_2_0_105:checkerr.sh,v 1.11 1999/02/05 02:04:21 woods Exp"
 #
 #    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
 #    Copyright (C) 1992  Ronald S. Karr
@@ -88,7 +88,7 @@ while read SPOOLDIR; do
 	x="`$SMAIL_PROGRAM -bv Postmaster 2>/dev/null`"
 	if [ "$x" ]; then
 	    (
-		sed -e "s/_SPOOLDIR_/$SPOOLDIR/g" $TMPDIR/.checkerr.msg
+		sed -e "s;_SPOOLDIR_;$SPOOLDIR;g" $TMPDIR/.chkerr.msg
 		echo ""
 		cat .checkerror
 	    ) | $SMAIL_PROGRAM -f"<+>" -eq -m Postmaster
@@ -169,7 +169,7 @@ while read SPOOLDIR; do
 	x="`$SMAIL_PROGRAM -bv Postmaster 2>/dev/null`"
 	if [ "$x" ]; then
 	    (
-		sed -e "s/_SPOOLDIR_/$SPOOLDIR/g" $TMPDIR/.checkerr.msg
+		sed -e "s;_SPOOLDIR_;$SPOOLDIR;g" $TMPDIR/.chkerr.msg
 		echo ""
 		cat .checkerror
 	    ) | $SMAIL_PROGRAM -f"<+>" -eq -m Postmaster
