@@ -1,5 +1,9 @@
 #! /bin/sh
+:
+#ident	"@(#)smail/util:RELEASE-3_2_0_105:smailbug.sh,v 1.4 1999/02/03 03:26:34 woods Exp"
+#
 # Submit a problem report to a GNATS site.
+#
 # Copyright (C) 1993 Free Software Foundation, Inc.
 # Contributed by Brendan Kehoe (brendan@cygnus.com), based on a
 # version written by Heinz G. Seidl (hgs@cygnus.com).
@@ -65,17 +69,43 @@ fi
 # How to read the passwd database.
 PASSWD="cat /etc/passwd"
 
-ECHON=sysv
-
-if [ $ECHON = bsd ] ; then
-  ECHON1="echo -n"
-  ECHON2=
-elif [ $ECHON = sysv ] ; then
-  ECHON1=echo
-  ECHON2='\c'
+# XXX this "echo" determination is cut&paste from my .profile <woods@planix.com>
+HAVEPRINT=false ; export HAVEPRINT
+if expr "`type print`" : '^print is shell builtint$' >/dev/null 2>&1 ; then
+	HAVEPRINT=true
+fi
+HAVEPRINTF=false ; export HAVEPRINTF
+if expr "`type printf`" : '^printf is shell builtint$' >/dev/null 2>&1 ; then
+	HAVEPRINTF=true
+elif expr "`type printf`" : '.* is .*/printf$' >/dev/null 2>&1 ; then
+	HAVEPRINTF=true
+fi
+if $HAVEPRINT ; then
+	# use ``$echo'' if any of the other variables...
+	echo=print
+	nl='\n'
+	n=''
+	c='\c'
+elif $HAVEPRINTF ; then
+	# use ``$echo'' if any of the other variables...
+	echo=printf
+	nl='\n'
+	n=''
+	c='\c'
 else
-  ECHON1=echo
-  ECHON2=
+	echo=echo
+	(echo "hi there\c" ; echo " ") >$HOME/echotmp
+	# Configure checks to make sure grep returns a status...
+	if grep c $HOME/echotmp >/dev/null 2>&1 ; then
+		nl=''
+		n='-n'
+		c=''
+	else
+		nl='\n'
+		n=''
+		c='\c'
+	fi
+	rm -f $HOME/echotmp
 fi
 
 #
@@ -461,7 +491,7 @@ while [ -z "$REQUEST_ID" ]; do
 
   while true; do
     if [ -z "$BATCH" ]; then
-      $ECHON1 "a)bort, e)dit or s)end? $ECHON2"
+      $echo $n "a)bort, e)dit or s)end? $c"
       read input
     else
       if [ $CNT -eq 5 ]; then
